/****************************************************************************
** Meta object code from reading C++ file 'adblockurlinterceptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../angelfish-26.07.80/src/adblockurlinterceptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'adblockurlinterceptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21AdblockUrlInterceptorE_t {};
} // unnamed namespace

template <> constexpr inline auto AdblockUrlInterceptor::qt_create_metaobjectdata<qt_meta_tag_ZN21AdblockUrlInterceptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AdblockUrlInterceptor",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "downloadNeededChanged",
        "",
        "enabledChanged",
        "adblockInitialized",
        "resetAdblock",
        "getCosmeticFilters",
        "std::vector<QString>",
        "QUrl",
        "url",
        "classes",
        "ids",
        "getInjectedScript",
        "downloadNeeded",
        "enabled",
        "adblockSupported"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'downloadNeededChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'adblockInitialized'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'resetAdblock'
        QtMocHelpers::MethodData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'getCosmeticFilters'
        QtMocHelpers::MethodData<std::vector<QString>(const QUrl &, const std::vector<QString> &, const std::vector<QString> &) const>(10, 6, QMC::AccessPublic, 0x80000000 | 11, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 11, 14 }, { 0x80000000 | 11, 15 },
        }}),
        // Method 'getInjectedScript'
        QtMocHelpers::MethodData<QString(const QUrl &) const>(16, 6, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 12, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'downloadNeeded'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'adblockSupported'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<AdblockUrlInterceptor, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AdblockUrlInterceptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QWebEngineUrlRequestInterceptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21AdblockUrlInterceptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21AdblockUrlInterceptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21AdblockUrlInterceptorE_t>.metaTypes,
    nullptr
} };

void AdblockUrlInterceptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AdblockUrlInterceptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->downloadNeededChanged(); break;
        case 1: _t->enabledChanged(); break;
        case 2: _t->adblockInitialized(); break;
        case 3: _t->resetAdblock(); break;
        case 4: { std::vector<QString> _r = _t->getCosmeticFilters((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<std::vector<QString>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<std::vector<QString>>>(_a[3])));
            if (_a[0]) *reinterpret_cast<std::vector<QString>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->getInjectedScript((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AdblockUrlInterceptor::*)()>(_a, &AdblockUrlInterceptor::downloadNeededChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AdblockUrlInterceptor::*)()>(_a, &AdblockUrlInterceptor::enabledChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AdblockUrlInterceptor::*)()>(_a, &AdblockUrlInterceptor::adblockInitialized, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->downloadNeeded(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->adblockSupported(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AdblockUrlInterceptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AdblockUrlInterceptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21AdblockUrlInterceptorE_t>.strings))
        return static_cast<void*>(this);
    return QWebEngineUrlRequestInterceptor::qt_metacast(_clname);
}

int AdblockUrlInterceptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWebEngineUrlRequestInterceptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void AdblockUrlInterceptor::downloadNeededChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AdblockUrlInterceptor::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AdblockUrlInterceptor::adblockInitialized()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
