/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<adblockfilterlistsmodel.h>)
#  include <adblockfilterlistsmodel.h>
#endif
#if __has_include(<adblockurlinterceptor.h>)
#  include <adblockurlinterceptor.h>
#endif
#if __has_include(<downloadsmodel.h>)
#  include <downloadsmodel.h>
#endif
#if __has_include(<interfaceloader.h>)
#  include <interfaceloader.h>
#endif
#if __has_include(<webappcreator.h>)
#  include <webappcreator.h>
#endif
#if __has_include(<webappmanagermodel.h>)
#  include <webappmanagermodel.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_angelfish()
{
    qmlRegisterModule("org.kde.angelfish", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<AdblockFilterListsModel>("org.kde.angelfish", 254);
    qmlRegisterTypesAndRevisions<AdblockUrlInterceptor>("org.kde.angelfish", 254);
    qmlRegisterTypesAndRevisions<DownloadsModel>("org.kde.angelfish", 254);
    qmlRegisterTypesAndRevisions<InterfaceLoader>("org.kde.angelfish", 254);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QWebEngineUrlRequestInterceptor *>().id();
    qmlRegisterTypesAndRevisions<WebAppCreator>("org.kde.angelfish", 254);
    qmlRegisterTypesAndRevisions<WebAppManagerModel>("org.kde.angelfish", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.angelfish", 254, 254);
}

static const QQmlModuleRegistration orgkdeangelfishRegistration("org.kde.angelfish", qml_register_types_org_kde_angelfish);
