/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<angelfishsettings.h>)
#  include <angelfishsettings.h>
#endif
#if __has_include(<angelfishwebprofile.h>)
#  include <angelfishwebprofile.h>
#endif
#if __has_include(<bookmarkshistorymodel.h>)
#  include <bookmarkshistorymodel.h>
#endif
#if __has_include(<browsermanager.h>)
#  include <browsermanager.h>
#endif
#if __has_include(<dbmanager.h>)
#  include <dbmanager.h>
#endif
#if __has_include(<domdistiller.h>)
#  include <domdistiller.h>
#endif
#if __has_include(<tabsmodel.h>)
#  include <tabsmodel.h>
#endif
#if __has_include(<urlobserver.h>)
#  include <urlobserver.h>
#endif
#if __has_include(<urlutils.h>)
#  include <urlutils.h>
#endif
#if __has_include(<useragent.h>)
#  include <useragent.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_angelfish_core()
{
    qmlRegisterModule("org.kde.angelfish.core", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<AngelfishSettings>("org.kde.angelfish.core", 254);
    qmlRegisterTypesAndRevisions<AngelfishWebProfile>("org.kde.angelfish.core", 254);
    qmlRegisterAnonymousType<QQuickWebEngineProfile, 254>("org.kde.angelfish.core", 254);
    qmlRegisterTypesAndRevisions<BookmarksHistoryModel>("org.kde.angelfish.core", 254);
    qmlRegisterTypesAndRevisions<BrowserManager>("org.kde.angelfish.core", 254);
    qmlRegisterTypesAndRevisions<DBManager>("org.kde.angelfish.core", 254);
    qmlRegisterTypesAndRevisions<DomDistiller>("org.kde.angelfish.core", 254);
    QMetaType::fromType<KConfigSkeleton *>().id();
    QMetaType::fromType<KCoreConfigSkeleton *>().id();
    qmlRegisterEnum<KCoreConfigSkeleton::DisambiguateConstructor>("KCoreConfigSkeleton::DisambiguateConstructor");
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    qmlRegisterTypesAndRevisions<TabsModel>("org.kde.angelfish.core", 254);
    qmlRegisterTypesAndRevisions<UrlObserver>("org.kde.angelfish.core", 254);
    qmlRegisterTypesAndRevisions<UrlUtils>("org.kde.angelfish.core", 254);
    qmlRegisterTypesAndRevisions<UserAgent>("org.kde.angelfish.core", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.angelfish.core", 254, 254);
}

static const QQmlModuleRegistration orgkdeangelfishcoreRegistration("org.kde.angelfish.core", qml_register_types_org_kde_angelfish_core);
