/****************************************************************************
** Meta object code from reading C++ file 'angelfishsettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../angelfishsettings.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'angelfishsettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17AngelfishSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto AngelfishSettings::qt_create_metaobjectdata<qt_meta_tag_ZN17AngelfishSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AngelfishSettings",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "searchCustomUrlChanged",
        "",
        "homepageChanged",
        "showHomeButtonChanged",
        "showTabBarChanged",
        "searchBaseUrlChanged",
        "newTabUrlChanged",
        "switchToNewTabChanged",
        "profileChanged",
        "webAutoLoadImagesChanged",
        "webJavaScriptEnabledChanged",
        "webSmoothScrollingEnabledChanged",
        "webDarkModeEnabledChanged",
        "navBarMainMenuChanged",
        "navBarTabsChanged",
        "navBarBackChanged",
        "navBarForwardChanged",
        "navBarReloadChanged",
        "navBarContextMenuChanged",
        "windowXChanged",
        "windowYChanged",
        "windowWidthChanged",
        "windowHeightChanged",
        "adblockEnabledChanged",
        "adblockFilterUrlsChanged",
        "adblockFilterNamesChanged",
        "adblockFilterDownloadDismissedChanged",
        "searchCustomUrl",
        "isSearchCustomUrlImmutable",
        "homepage",
        "QUrl",
        "isHomepageImmutable",
        "defaultHomepageValue",
        "showHomeButton",
        "isShowHomeButtonImmutable",
        "defaultShowHomeButtonValue",
        "showTabBar",
        "isShowTabBarImmutable",
        "defaultShowTabBarValue",
        "searchBaseUrl",
        "isSearchBaseUrlImmutable",
        "defaultSearchBaseUrlValue",
        "newTabUrl",
        "isNewTabUrlImmutable",
        "defaultNewTabUrlValue",
        "switchToNewTab",
        "isSwitchToNewTabImmutable",
        "defaultSwitchToNewTabValue",
        "profile",
        "isProfileImmutable",
        "defaultProfileValue",
        "webAutoLoadImages",
        "isWebAutoLoadImagesImmutable",
        "defaultWebAutoLoadImagesValue",
        "webJavaScriptEnabled",
        "isWebJavaScriptEnabledImmutable",
        "defaultWebJavaScriptEnabledValue",
        "webSmoothScrollingEnabled",
        "isWebSmoothScrollingEnabledImmutable",
        "defaultWebSmoothScrollingEnabledValue",
        "webDarkModeEnabled",
        "isWebDarkModeEnabledImmutable",
        "defaultWebDarkModeEnabledValue",
        "navBarMainMenu",
        "isNavBarMainMenuImmutable",
        "defaultNavBarMainMenuValue",
        "navBarTabs",
        "isNavBarTabsImmutable",
        "defaultNavBarTabsValue",
        "navBarBack",
        "isNavBarBackImmutable",
        "defaultNavBarBackValue",
        "navBarForward",
        "isNavBarForwardImmutable",
        "defaultNavBarForwardValue",
        "navBarReload",
        "isNavBarReloadImmutable",
        "defaultNavBarReloadValue",
        "navBarContextMenu",
        "isNavBarContextMenuImmutable",
        "windowX",
        "isWindowXImmutable",
        "windowY",
        "isWindowYImmutable",
        "windowWidth",
        "isWindowWidthImmutable",
        "defaultWindowWidthValue",
        "windowHeight",
        "isWindowHeightImmutable",
        "defaultWindowHeightValue",
        "adblockEnabled",
        "isAdblockEnabledImmutable",
        "defaultAdblockEnabledValue",
        "adblockFilterUrls",
        "QList<QUrl>",
        "isAdblockFilterUrlsImmutable",
        "defaultAdblockFilterUrlsValue",
        "adblockFilterNames",
        "isAdblockFilterNamesImmutable",
        "defaultAdblockFilterNamesValue",
        "adblockFilterDownloadDismissed",
        "isAdblockFilterDownloadDismissedImmutable",
        "defaultAdblockFilterDownloadDismissedValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'searchCustomUrlChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'homepageChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showHomeButtonChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showTabBarChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'searchBaseUrlChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newTabUrlChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'switchToNewTabChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'profileChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'webAutoLoadImagesChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'webJavaScriptEnabledChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'webSmoothScrollingEnabledChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'webDarkModeEnabledChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'navBarMainMenuChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'navBarTabsChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'navBarBackChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'navBarForwardChanged'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'navBarReloadChanged'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'navBarContextMenuChanged'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowXChanged'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowYChanged'
        QtMocHelpers::SignalData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowWidthChanged'
        QtMocHelpers::SignalData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowHeightChanged'
        QtMocHelpers::SignalData<void()>(27, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'adblockEnabledChanged'
        QtMocHelpers::SignalData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'adblockFilterUrlsChanged'
        QtMocHelpers::SignalData<void()>(29, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'adblockFilterNamesChanged'
        QtMocHelpers::SignalData<void()>(30, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'adblockFilterDownloadDismissedChanged'
        QtMocHelpers::SignalData<void()>(31, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'searchCustomUrl'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isSearchCustomUrlImmutable'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'homepage'
        QtMocHelpers::PropertyData<QUrl>(34, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'isHomepageImmutable'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultHomepageValue'
        QtMocHelpers::PropertyData<QUrl>(37, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'showHomeButton'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isShowHomeButtonImmutable'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowHomeButtonValue'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showTabBar'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isShowTabBarImmutable'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowTabBarValue'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'searchBaseUrl'
        QtMocHelpers::PropertyData<QUrl>(44, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'isSearchBaseUrlImmutable'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSearchBaseUrlValue'
        QtMocHelpers::PropertyData<QUrl>(46, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'newTabUrl'
        QtMocHelpers::PropertyData<QUrl>(47, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'isNewTabUrlImmutable'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNewTabUrlValue'
        QtMocHelpers::PropertyData<QUrl>(49, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'switchToNewTab'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isSwitchToNewTabImmutable'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSwitchToNewTabValue'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'profile'
        QtMocHelpers::PropertyData<QString>(53, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isProfileImmutable'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultProfileValue'
        QtMocHelpers::PropertyData<QString>(55, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'webAutoLoadImages'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isWebAutoLoadImagesImmutable'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWebAutoLoadImagesValue'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'webJavaScriptEnabled'
        QtMocHelpers::PropertyData<bool>(59, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isWebJavaScriptEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWebJavaScriptEnabledValue'
        QtMocHelpers::PropertyData<bool>(61, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'webSmoothScrollingEnabled'
        QtMocHelpers::PropertyData<bool>(62, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isWebSmoothScrollingEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(63, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWebSmoothScrollingEnabledValue'
        QtMocHelpers::PropertyData<bool>(64, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'webDarkModeEnabled'
        QtMocHelpers::PropertyData<bool>(65, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isWebDarkModeEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(66, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWebDarkModeEnabledValue'
        QtMocHelpers::PropertyData<bool>(67, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'navBarMainMenu'
        QtMocHelpers::PropertyData<bool>(68, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isNavBarMainMenuImmutable'
        QtMocHelpers::PropertyData<bool>(69, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNavBarMainMenuValue'
        QtMocHelpers::PropertyData<bool>(70, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'navBarTabs'
        QtMocHelpers::PropertyData<bool>(71, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isNavBarTabsImmutable'
        QtMocHelpers::PropertyData<bool>(72, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNavBarTabsValue'
        QtMocHelpers::PropertyData<bool>(73, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'navBarBack'
        QtMocHelpers::PropertyData<bool>(74, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isNavBarBackImmutable'
        QtMocHelpers::PropertyData<bool>(75, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNavBarBackValue'
        QtMocHelpers::PropertyData<bool>(76, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'navBarForward'
        QtMocHelpers::PropertyData<bool>(77, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'isNavBarForwardImmutable'
        QtMocHelpers::PropertyData<bool>(78, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNavBarForwardValue'
        QtMocHelpers::PropertyData<bool>(79, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'navBarReload'
        QtMocHelpers::PropertyData<bool>(80, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'isNavBarReloadImmutable'
        QtMocHelpers::PropertyData<bool>(81, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNavBarReloadValue'
        QtMocHelpers::PropertyData<bool>(82, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'navBarContextMenu'
        QtMocHelpers::PropertyData<bool>(83, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'isNavBarContextMenuImmutable'
        QtMocHelpers::PropertyData<bool>(84, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'windowX'
        QtMocHelpers::PropertyData<int>(85, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'isWindowXImmutable'
        QtMocHelpers::PropertyData<bool>(86, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'windowY'
        QtMocHelpers::PropertyData<int>(87, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'isWindowYImmutable'
        QtMocHelpers::PropertyData<bool>(88, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'windowWidth'
        QtMocHelpers::PropertyData<int>(89, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'isWindowWidthImmutable'
        QtMocHelpers::PropertyData<bool>(90, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWindowWidthValue'
        QtMocHelpers::PropertyData<int>(91, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'windowHeight'
        QtMocHelpers::PropertyData<int>(92, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'isWindowHeightImmutable'
        QtMocHelpers::PropertyData<bool>(93, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWindowHeightValue'
        QtMocHelpers::PropertyData<int>(94, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'adblockEnabled'
        QtMocHelpers::PropertyData<bool>(95, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'isAdblockEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(96, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAdblockEnabledValue'
        QtMocHelpers::PropertyData<bool>(97, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'adblockFilterUrls'
        QtMocHelpers::PropertyData<QList<QUrl>>(98, 0x80000000 | 99, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 23),
        // property 'isAdblockFilterUrlsImmutable'
        QtMocHelpers::PropertyData<bool>(100, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAdblockFilterUrlsValue'
        QtMocHelpers::PropertyData<QList<QUrl>>(101, 0x80000000 | 99, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'adblockFilterNames'
        QtMocHelpers::PropertyData<QStringList>(102, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 24),
        // property 'isAdblockFilterNamesImmutable'
        QtMocHelpers::PropertyData<bool>(103, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAdblockFilterNamesValue'
        QtMocHelpers::PropertyData<QStringList>(104, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'adblockFilterDownloadDismissed'
        QtMocHelpers::PropertyData<bool>(105, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 25),
        // property 'isAdblockFilterDownloadDismissedImmutable'
        QtMocHelpers::PropertyData<bool>(106, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAdblockFilterDownloadDismissedValue'
        QtMocHelpers::PropertyData<bool>(107, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<AngelfishSettings, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AngelfishSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17AngelfishSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17AngelfishSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17AngelfishSettingsE_t>.metaTypes,
    nullptr
} };

void AngelfishSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AngelfishSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->searchCustomUrlChanged(); break;
        case 1: _t->homepageChanged(); break;
        case 2: _t->showHomeButtonChanged(); break;
        case 3: _t->showTabBarChanged(); break;
        case 4: _t->searchBaseUrlChanged(); break;
        case 5: _t->newTabUrlChanged(); break;
        case 6: _t->switchToNewTabChanged(); break;
        case 7: _t->profileChanged(); break;
        case 8: _t->webAutoLoadImagesChanged(); break;
        case 9: _t->webJavaScriptEnabledChanged(); break;
        case 10: _t->webSmoothScrollingEnabledChanged(); break;
        case 11: _t->webDarkModeEnabledChanged(); break;
        case 12: _t->navBarMainMenuChanged(); break;
        case 13: _t->navBarTabsChanged(); break;
        case 14: _t->navBarBackChanged(); break;
        case 15: _t->navBarForwardChanged(); break;
        case 16: _t->navBarReloadChanged(); break;
        case 17: _t->navBarContextMenuChanged(); break;
        case 18: _t->windowXChanged(); break;
        case 19: _t->windowYChanged(); break;
        case 20: _t->windowWidthChanged(); break;
        case 21: _t->windowHeightChanged(); break;
        case 22: _t->adblockEnabledChanged(); break;
        case 23: _t->adblockFilterUrlsChanged(); break;
        case 24: _t->adblockFilterNamesChanged(); break;
        case 25: _t->adblockFilterDownloadDismissedChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::searchCustomUrlChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::homepageChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::showHomeButtonChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::showTabBarChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::searchBaseUrlChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::newTabUrlChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::switchToNewTabChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::profileChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::webAutoLoadImagesChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::webJavaScriptEnabledChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::webSmoothScrollingEnabledChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::webDarkModeEnabledChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::navBarMainMenuChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::navBarTabsChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::navBarBackChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::navBarForwardChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::navBarReloadChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::navBarContextMenuChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::windowXChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::windowYChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::windowWidthChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::windowHeightChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::adblockEnabledChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::adblockFilterUrlsChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::adblockFilterNamesChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (AngelfishSettings::*)()>(_a, &AngelfishSettings::adblockFilterDownloadDismissedChanged, 25))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->searchCustomUrl(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isSearchCustomUrlImmutable(); break;
        case 2: *reinterpret_cast<QUrl*>(_v) = _t->homepage(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isHomepageImmutable(); break;
        case 4: *reinterpret_cast<QUrl*>(_v) = _t->defaultHomepageValue(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->showHomeButton(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isShowHomeButtonImmutable(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->defaultShowHomeButtonValue(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->showTabBar(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isShowTabBarImmutable(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->defaultShowTabBarValue(); break;
        case 11: *reinterpret_cast<QUrl*>(_v) = _t->searchBaseUrl(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->isSearchBaseUrlImmutable(); break;
        case 13: *reinterpret_cast<QUrl*>(_v) = _t->defaultSearchBaseUrlValue(); break;
        case 14: *reinterpret_cast<QUrl*>(_v) = _t->newTabUrl(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->isNewTabUrlImmutable(); break;
        case 16: *reinterpret_cast<QUrl*>(_v) = _t->defaultNewTabUrlValue(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->switchToNewTab(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->isSwitchToNewTabImmutable(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->defaultSwitchToNewTabValue(); break;
        case 20: *reinterpret_cast<QString*>(_v) = _t->profile(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->isProfileImmutable(); break;
        case 22: *reinterpret_cast<QString*>(_v) = _t->defaultProfileValue(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->webAutoLoadImages(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->isWebAutoLoadImagesImmutable(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->defaultWebAutoLoadImagesValue(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->webJavaScriptEnabled(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->isWebJavaScriptEnabledImmutable(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->defaultWebJavaScriptEnabledValue(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->webSmoothScrollingEnabled(); break;
        case 30: *reinterpret_cast<bool*>(_v) = _t->isWebSmoothScrollingEnabledImmutable(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->defaultWebSmoothScrollingEnabledValue(); break;
        case 32: *reinterpret_cast<bool*>(_v) = _t->webDarkModeEnabled(); break;
        case 33: *reinterpret_cast<bool*>(_v) = _t->isWebDarkModeEnabledImmutable(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->defaultWebDarkModeEnabledValue(); break;
        case 35: *reinterpret_cast<bool*>(_v) = _t->navBarMainMenu(); break;
        case 36: *reinterpret_cast<bool*>(_v) = _t->isNavBarMainMenuImmutable(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->defaultNavBarMainMenuValue(); break;
        case 38: *reinterpret_cast<bool*>(_v) = _t->navBarTabs(); break;
        case 39: *reinterpret_cast<bool*>(_v) = _t->isNavBarTabsImmutable(); break;
        case 40: *reinterpret_cast<bool*>(_v) = _t->defaultNavBarTabsValue(); break;
        case 41: *reinterpret_cast<bool*>(_v) = _t->navBarBack(); break;
        case 42: *reinterpret_cast<bool*>(_v) = _t->isNavBarBackImmutable(); break;
        case 43: *reinterpret_cast<bool*>(_v) = _t->defaultNavBarBackValue(); break;
        case 44: *reinterpret_cast<bool*>(_v) = _t->navBarForward(); break;
        case 45: *reinterpret_cast<bool*>(_v) = _t->isNavBarForwardImmutable(); break;
        case 46: *reinterpret_cast<bool*>(_v) = _t->defaultNavBarForwardValue(); break;
        case 47: *reinterpret_cast<bool*>(_v) = _t->navBarReload(); break;
        case 48: *reinterpret_cast<bool*>(_v) = _t->isNavBarReloadImmutable(); break;
        case 49: *reinterpret_cast<bool*>(_v) = _t->defaultNavBarReloadValue(); break;
        case 50: *reinterpret_cast<bool*>(_v) = _t->navBarContextMenu(); break;
        case 51: *reinterpret_cast<bool*>(_v) = _t->isNavBarContextMenuImmutable(); break;
        case 52: *reinterpret_cast<int*>(_v) = _t->windowX(); break;
        case 53: *reinterpret_cast<bool*>(_v) = _t->isWindowXImmutable(); break;
        case 54: *reinterpret_cast<int*>(_v) = _t->windowY(); break;
        case 55: *reinterpret_cast<bool*>(_v) = _t->isWindowYImmutable(); break;
        case 56: *reinterpret_cast<int*>(_v) = _t->windowWidth(); break;
        case 57: *reinterpret_cast<bool*>(_v) = _t->isWindowWidthImmutable(); break;
        case 58: *reinterpret_cast<int*>(_v) = _t->defaultWindowWidthValue(); break;
        case 59: *reinterpret_cast<int*>(_v) = _t->windowHeight(); break;
        case 60: *reinterpret_cast<bool*>(_v) = _t->isWindowHeightImmutable(); break;
        case 61: *reinterpret_cast<int*>(_v) = _t->defaultWindowHeightValue(); break;
        case 62: *reinterpret_cast<bool*>(_v) = _t->adblockEnabled(); break;
        case 63: *reinterpret_cast<bool*>(_v) = _t->isAdblockEnabledImmutable(); break;
        case 64: *reinterpret_cast<bool*>(_v) = _t->defaultAdblockEnabledValue(); break;
        case 65: *reinterpret_cast<QList<QUrl>*>(_v) = _t->adblockFilterUrls(); break;
        case 66: *reinterpret_cast<bool*>(_v) = _t->isAdblockFilterUrlsImmutable(); break;
        case 67: *reinterpret_cast<QList<QUrl>*>(_v) = _t->defaultAdblockFilterUrlsValue(); break;
        case 68: *reinterpret_cast<QStringList*>(_v) = _t->adblockFilterNames(); break;
        case 69: *reinterpret_cast<bool*>(_v) = _t->isAdblockFilterNamesImmutable(); break;
        case 70: *reinterpret_cast<QStringList*>(_v) = _t->defaultAdblockFilterNamesValue(); break;
        case 71: *reinterpret_cast<bool*>(_v) = _t->adblockFilterDownloadDismissed(); break;
        case 72: *reinterpret_cast<bool*>(_v) = _t->isAdblockFilterDownloadDismissedImmutable(); break;
        case 73: *reinterpret_cast<bool*>(_v) = _t->defaultAdblockFilterDownloadDismissedValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSearchCustomUrl(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setHomepage(*reinterpret_cast<QUrl*>(_v)); break;
        case 5: _t->setShowHomeButton(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setShowTabBar(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setSearchBaseUrl(*reinterpret_cast<QUrl*>(_v)); break;
        case 14: _t->setNewTabUrl(*reinterpret_cast<QUrl*>(_v)); break;
        case 17: _t->setSwitchToNewTab(*reinterpret_cast<bool*>(_v)); break;
        case 20: _t->setProfile(*reinterpret_cast<QString*>(_v)); break;
        case 23: _t->setWebAutoLoadImages(*reinterpret_cast<bool*>(_v)); break;
        case 26: _t->setWebJavaScriptEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 29: _t->setWebSmoothScrollingEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 32: _t->setWebDarkModeEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 35: _t->setNavBarMainMenu(*reinterpret_cast<bool*>(_v)); break;
        case 38: _t->setNavBarTabs(*reinterpret_cast<bool*>(_v)); break;
        case 41: _t->setNavBarBack(*reinterpret_cast<bool*>(_v)); break;
        case 44: _t->setNavBarForward(*reinterpret_cast<bool*>(_v)); break;
        case 47: _t->setNavBarReload(*reinterpret_cast<bool*>(_v)); break;
        case 50: _t->setNavBarContextMenu(*reinterpret_cast<bool*>(_v)); break;
        case 52: _t->setWindowX(*reinterpret_cast<int*>(_v)); break;
        case 54: _t->setWindowY(*reinterpret_cast<int*>(_v)); break;
        case 56: _t->setWindowWidth(*reinterpret_cast<int*>(_v)); break;
        case 59: _t->setWindowHeight(*reinterpret_cast<int*>(_v)); break;
        case 62: _t->setAdblockEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 65: _t->setAdblockFilterUrls(*reinterpret_cast<QList<QUrl>*>(_v)); break;
        case 68: _t->setAdblockFilterNames(*reinterpret_cast<QStringList*>(_v)); break;
        case 71: _t->setAdblockFilterDownloadDismissed(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AngelfishSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AngelfishSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17AngelfishSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int AngelfishSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 26;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 74;
    }
    return _id;
}

// SIGNAL 0
void AngelfishSettings::searchCustomUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AngelfishSettings::homepageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AngelfishSettings::showHomeButtonChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AngelfishSettings::showTabBarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AngelfishSettings::searchBaseUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AngelfishSettings::newTabUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void AngelfishSettings::switchToNewTabChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void AngelfishSettings::profileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void AngelfishSettings::webAutoLoadImagesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void AngelfishSettings::webJavaScriptEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void AngelfishSettings::webSmoothScrollingEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void AngelfishSettings::webDarkModeEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void AngelfishSettings::navBarMainMenuChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void AngelfishSettings::navBarTabsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void AngelfishSettings::navBarBackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void AngelfishSettings::navBarForwardChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void AngelfishSettings::navBarReloadChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void AngelfishSettings::navBarContextMenuChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void AngelfishSettings::windowXChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void AngelfishSettings::windowYChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void AngelfishSettings::windowWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void AngelfishSettings::windowHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void AngelfishSettings::adblockEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void AngelfishSettings::adblockFilterUrlsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void AngelfishSettings::adblockFilterNamesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void AngelfishSettings::adblockFilterDownloadDismissedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}
QT_WARNING_POP
